==> 3.5.12-core.tar: kdewebdev/kommander/widgets/progressbar.h <==
/***************************************************************************
                          progressbar.h - ProgressBar widget 
                             -------------------
    copyright            : (C) 2004      Michal Rudolf <mrudolf@kdewebdev.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _HAVE_PROGRESSBAR_H_
#define _HAVE_PROGRESSBAR_H_

/* KDE INCLUDES */

/* QT INCLUDES */
#include <tqstringlist.h>
#include <tqobject.h>
#include <tqstring.h>

/* OTHER INCLUDES */
#include <kprogress.h>
#include <kommanderwidget.h>

class TQWidget;

class TQShowEvent;
class KOMMANDER_EXPORT ProgressBar: public KProgress, public KommanderWidget
{
  Q_OBJECT

  Q_PROPERTY(TQString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
  Q_PROPERTY(TQStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
  Q_PROPERTY(bool KommanderWidget READ isKommanderWidget)
  
public:
  ProgressBar(TQWidget *a_parent, const char *a_name);
  ~ProgressBar();

  virtual bool isKommanderWidget() const;
  virtual void setAssociatedText(const TQStringList&);
  virtual TQStringList associatedText() const;
  virtual TQString currentState() const;
  virtual TQString populationText() const;
  virtual void setPopulationText(const TQString&);

  virtual TQString handleDCOP(int function, const TQStringList& args);
  virtual bool isFunctionSupported(int function);
public slots:
  virtual void populate();
signals:
  void widgetOpened();
protected:
  void showEvent(TQShowEvent *e);
private:
};

#endif

==> 3.5.13-core.tar: kdewebdev/kommander/widgets/progressbar.h <==
/***************************************************************************
                          progressbar.h - ProgressBar widget 
                             -------------------
    copyright            : (C) 2004      Michal Rudolf <mrudolf@kdewebdev.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _HAVE_PROGRESSBAR_H_
#define _HAVE_PROGRESSBAR_H_

/* KDE INCLUDES */

/* QT INCLUDES */
#include <tqstringlist.h>
#include <tqobject.h>
#include <tqstring.h>

/* OTHER INCLUDES */
#include <kprogress.h>
#include <kommanderwidget.h>

class TQWidget;

class TQShowEvent;
class KOMMANDER_EXPORT ProgressBar: public KProgress, public KommanderWidget
{
  Q_OBJECT
  TQ_OBJECT

  TQ_PROPERTY(TQString populationText READ populationText WRITE setPopulationText DESIGNABLE false)
  TQ_PROPERTY(TQStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
  TQ_PROPERTY(bool KommanderWidget READ isKommanderWidget)
  
public:
  ProgressBar(TQWidget *a_parent, const char *a_name);
  ~ProgressBar();

  virtual bool isKommanderWidget() const;
  virtual void setAssociatedText(const TQStringList&);
  virtual TQStringList associatedText() const;
  virtual TQString currentState() const;
  virtual TQString populationText() const;
  virtual void setPopulationText(const TQString&);

  virtual TQString handleDCOP(int function, const TQStringList& args);
  virtual bool isFunctionSupported(int function);
public slots:
  virtual void populate();
signals:
  void widgetOpened();
protected:
  void showEvent(TQShowEvent *e);
private:
};

#endif
